# State
STATE_NORMAL = "normal"
STATE_ACTIVE = "active"
STATE_DISABLED = "disabled"

# Fill
FILL_NONE = "none"
FILL_WIDTH = "x"
FILL_HEIGHT = "y"
FILL_BOTH = "both"

# Expand
EXPAND_NO = "no"
EXPAND_YES = "yes"

# Side
SIDE_LEFT = "left"
SIDE_RIGHT = "right"
SIDE_TOP = "top"
SIDE_BOTTOM = "bottom"

# Anchor
ANCHOR_NW = "nw"
ANCHOR_N = "n"
ANCHOR_NE = "ne"
ANCHOR_W = "w"
ANCHOR_CENTER = "center"
ANCHOR_E = "e"
ANCHOR_SW = "sw"
ANCHOR_S = "s"
ANCHOR_SE = "se"

# Justify
JUSTIFY_LEFT = "left"
JUSTIFY_CENTER = "center"
JUSTIFY_RIGHT = "right"

# Style
STYLE_LIGHT = "light"
STYLE_DARK = "dark"
STYLE_AUTO = "auto"

# Button
EVENT_BUTTON1 = "<Button-1>"
EVENT_BUTTON2 = "<Button-2>"
EVENT_BUTTON3 = "<Button-3>"
EVENT_BUTTON_ALL = "<Button>"
EVENT_BUTTON_PRESS = "<ButtonPress>"

# Button Release
EVENT_BUTTON1_RELEASE = "<ButtonRelease-1>"
EVENT_BUTTON2_RELEASE = "<ButtonRelease-2>"
EVENT_BUTTON3_RELEASE = "<ButtonRelease-3>"
EVENT_BUTTON_ALL_RELEASE = "<ButtonRelease>"

# Double Button
EVENT_BUTTON1_DOUBLE = "<Double-Button-1>"
EVENT_BUTTON2_DOUBLE = "<Double-Button-2>"
EVENT_BUTTON3_DOUBLE = "<Double-Button-3>"
EVENT_BUTTON_ALL_DOUBLE = "<Double-Button>"
EVENT_BUTTON_PRESS_DOUBLE = "<Double-ButtonPress>"

# Triple Button
EVENT_BUTTON1_TRIPLE = "<Triple-Button-1>"
EVENT_BUTTON2_TRIPLE = "<Triple-Button-2>"
EVENT_BUTTON3_TRIPLE = "<Triple-Button-3>"
EVENT_BUTTON_ALL_TRIPLE = "<Triple-Button>"
EVENT_BUTTON_PRESS_TRIPLE = "<Triple-ButtonPress>"

# Event
EVENT_ENTER = "<Enter>"
EVENT_LEAVE = "<Leave>"

EVENT_CONFIGURE = "<Configure>"

EVENT_DESTROY = "<Destroy>"

EVENT_FOCUS_IN = "<FocusIn>"
EVENT_FOCUS_OUT = "<FocusOut>"

# Event Ex
EVENT_EX_DELETE_WINDOW = "WM_DELETE_WINDOW"
EVENT_EX_DELETE_WINDOW = "WM_SAVE_YOURSELF"

ATTRIBUTE_ALPHA = "-alpha"
ATTRIBUTE_TOPPING = "-topmost"
ATTRIBUTE_MODIFIED = "-modified"
ATTRIBUTE_TOOLWINDOW = "-toolwindow"
ATTRIBUTE_TRANSPARENT = "-transparent"

# Orient
ORIENT_HORIZONTAL = "horizontal"
ORIENT_VERTICAL = "vertical"

# Progress Mode
PROGRESS_MODE_DETERMINATE = "determinate"
PROGRESS_MODE_INDETERMINATE = "indeterminate"